==> syue-cli-0.2.2.tgz: package/config/webpack.config.base.js <==
const path = require("path")
const webpack = require("webpack")
const _ = require('lodash')
const util = require('../util')
const chalk = require('chalk')

const dirname = process.cwd()
const userConfig = readUserConfig(dirname)
const { webpackConfig, templates } = generateWebpackConfig(userConfig)

function readUserConfig (dirname) {
  if (process.argv.length > 2) {
    console.log(`构建页面：${process.argv[2]}`)
    const configFilePath = path.resolve(dirname, 'cli-config', `index.js`)
    if (util.isFile(configFilePath)) {
      return require(configFilePath)[process.argv[2]] || {}
    }
  }
  return util.isFile(path.resolve(dirname, 'sy.config.js')) ? require(path.resolve(dirname, 'sy.config'))
    : require(path.resolve(dirname, 'webpack.config'))
}

function generateWebpackConfig ({ context = dirname, runtimeOnly = true, files, exclude, index = path.join(__dirname, 'template.html') }) {
  if (!files) {
    throw new Error('编译失败,没有可编译的模块，检查files入口文件配置')
  }

  // 格式化files配置
  files = handleFiles(files, index)
  const entry = {}
  const templates = []
  _.each(files, (templatePath, filePath) => {
    if (!_.includes(filePath.split('/'), 'src')) {
      console.error(chalk.bold.red('\n编译失败,' + filePath + '中没有src目录\n'))
      process.exit(-1)
    }
    solveEntry(entry, templates, filePath, templatePath)
  })

  // 排除的目录
  exclude = _.isObject(exclude) ? exclude : exclude ? /node_modules/ : undefined

  const webpackConfig = {
    // 根目录,entry的入口文件
    context,
    // string | object | array
    entry,
    output: {
      // 静态文件访问路径
      publicPath: './',
      // 输出文件的地址
      path: context,
      // 输出的文件名 hash统一生成,chunkhash变化生成
      filename: '[name].js',
      // 输出块的名字
      chunkFilename: '[name].[chunkhash:8].js'
    },
    resolve: {
      extensions: ['.js', '.json', '.vue', '.jsx'],
      alias: {
        'vue$': `vue/dist/vue.${runtimeOnly === false ? '' : 'runtime.'}esm.js`,
        'components': path.join(context, 'components'),
        'pages': path.join(context, 'pages'),
        '@': path.resolve(context)
      }
    },
    module: {
      rules: [
        // linter:standard
        {
          test: /\.(jsx?|vue)$/,
          enforce: 'pre',
          loader: 'eslint-loader',
          exclude: /node_modules/,
          include: context
        },

        //babel
        {
          test: /\.(jsx|js)?$/,
          loader: 'babel-loader',
          exclude: exclude,
          options: {
            cacheDirectory: true
          }
        },
        // 模版
        {
          test: /\.html$/,
          loader: 'html-loader',
          options: {
            interpolate: true
          }
        },

        {
          test: /\.hbs$/,
          loader: 'handlebars-loader'
        },
        {
          test: /\.(woff|svg|eot|ttf)\??.*$/,
          use: {
            loader: 'url-loader',
            options: {
              name (file) {

                return `${templates[0].basePath}/font/[name].[ext]`
              },
              limit: 20000
            }
          }
        },
        // 其他
        {
          exclude: [
            /\.vue$/,
            /\.(js|jsx)$/,
            /\.css$/,
            /\.styl$/,
            /\.sass$/,
            /\.scss$/,
            /\.less$/,
            /\.json$/,
            /\.html$/,
            /\.(woff|svg|eot|ttf)\??.*$/,
            /\.hbs$/
          ],
          loader: 'url-loader',
          options: {
            limit: 1000,
            publicPath: './',
            // outputPath: commonsChunkPath + '/',
            // name: '[path][name].[hash:8].[ext]'
            name (file) {
              const paths = file.replace(context, '').split('/')
              const res = []
              paths.forEach((path, index) => {
                if (path && index !== paths.length - 1) {
                  res.push(path === 'src' ? 'dist' : path)
                }
              })
              const path = res.join('/')
              return path + '/[name].[hash:8].[ext]'
            }
          }
        }
      ]
    }
  }

  return {
    webpackConfig,
    templates
  }
}

// 处理文件入口路径问题, 处理不是很严谨
function solveEntry (entry, templates, filePath, templatePath) {
  let entryPath = filePath
  if (_.includes(filePath, '.')) {
    entryPath = entryPath.substring(0, entryPath.lastIndexOf('.'))
  }

  // const index = entryPath.indexOf('src')
  entryPath = entryPath.replace('src', 'dist')
  // const filename = index > 0 ? entryPath.substring(0, index - 1) : 'index'

  entry[entryPath] = './' + filePath
  templates.push({
    filePath,
    filename: entryPath + '.html',
    template: templatePath,
    chunk: entryPath,
    basePath: entryPath.substring(0, entryPath.indexOf('dist') + 4)
  })
}

// 将文件处理成统一格式
function handleFiles (files, index) {
  const res = {}
  _.each(files, (item, key) => {
    // 对象形式
    if (_.isString(key)) {
      if (item === 1) {
        res[key] = index
      } else if (_.isString(item)) {
        res[key] = item
      }
    } else {
      if (_.isString(item)) {
        res[item] = index
      } else if (_.isArray(item)) {
        res[item[0]] = item[1]
      }
    }
  })

  return res
}

module.exports = {
  userConfig,
  webpackConfig,
  templates
}

==> syue-cli-0.3.2.tgz: package/config/webpack.config.base.js <==
const path = require("path")
const webpack = require("webpack")
const _ = require('lodash')
const util = require('../util')
const chalk = require('chalk')


const dirname = process.cwd()
const userConfig = readUserConfig(dirname)
const { webpackConfig, templates } = generateWebpackConfig(userConfig)
function readUserConfig (dirname) {
  if (process.argv.length > 2 && process.argv[2]) {
    console.log(`构建页面：${process.argv[2]}`)
    const configFilePath = path.resolve(dirname, 'cli-config', `index.js`)
    if (util.isFile(configFilePath)) {
      return require(configFilePath)[process.argv[2]] || {}
    }
  }
  return util.isFile(path.resolve(dirname, 'sy.config.js')) ? require(path.resolve(dirname, 'sy.config'))
    : require(path.resolve(dirname, 'webpack.config'))
}

function generateWebpackConfig ({ context = dirname, runtimeOnly = true, files, exclude, index = path.join(__dirname, 'template.html') }) {
  if (!files) {
    throw new Error('编译失败,没有可编译的模块，检查files入口文件配置')
  }

  // 格式化files配置
  files = handleFiles(files, index)
  const entry = {}
  const templates = []
  _.each(files, (templatePath, filePath) => {
    if (!_.includes(filePath.split('/'), 'src')) {
      console.error(chalk.bold.red('\n编译失败,' + filePath + '中没有src目录\n'))
      process.exit(-1)
    }
    solveEntry(entry, templates, filePath, templatePath)
  })

  // 排除的目录
  exclude = _.isObject(exclude) ? exclude : exclude ? /node_modules/ : undefined

  const webpackConfig = {
    // 根目录,entry的入口文件
    context,
    // string | object | array
    entry,
    output: {
      // 静态文件访问路径
      publicPath: './',
      // 输出文件的地址
      path: context,
      // 输出的文件名 hash统一生成,chunkhash变化生成
      filename: '[name].js',
      // 输出块的名字
      chunkFilename: '[name].[chunkhash:8].js'
    },
    resolve: {
      extensions: ['.js', '.json', '.vue', '.jsx'],
      alias: {
        'vue$': `vue/dist/vue.${runtimeOnly === false ? '' : 'runtime.'}esm.js`,
        'components': path.join(context, 'components'),
        'pages': path.join(context, 'pages'),
        '@': path.resolve(context)
      }
    },
    module: {
      rules: [
        // linter:standard
        {
          test: /\.(jsx?|vue)$/,
          enforce: 'pre',
          use: [
            "thread-loader",
            'eslint-loader'
          ],
          // loader: 'eslint-loader',
          exclude: /node_modules/,
          include: context
        },
        // {
        //   test: /\.(jsx?|vue)$/,
        //   enforce: 'pre',
        //   loader: 'happypack/loader?id=happyEslint',
        //   exclude: /node_modules/,
        //   include: context
        // },
        

        //babel
        {
          test: /\.(jsx|js)?$/,
          // loader: 'babel-loader',
          use: [
            "thread-loader",
            {
              loader: 'babel-loader',
              options: {
                cacheDirectory: true
              }
            }
          ],
          exclude: exclude,
        },
        // {
        //   test: /\.(jsx|js)?$/,
        //   loader: 'happypack/loader?id=happyBabel',
        //   exclude: exclude
        // },
        // 模版
        // {
        //   test: /\.html$/,
        //   loader: 'html-loader',
        //   options: {
        //     interpolate: true
        //   }
        // },

        {
          test: /\.hbs$/,
          loader: 'handlebars-loader'
        },
        {
          test: /\.(woff|svg|eot|ttf)\??.*$/,
          use: {
            loader: 'url-loader',
            options: {
              name (file) {

                return `${templates[0].basePath}/font/[name].[ext]`
              },
              limit: 20000
            }
          }
        },
        // 其他
        {
          exclude: [
            /\.vue$/,
            /\.(js|jsx)$/,
            /\.css$/,
            /\.styl$/,
            /\.sass$/,
            /\.scss$/,
            /\.less$/,
            /\.html$/,
            /\.json$/,
            /\.(woff|svg|eot|ttf)\??.*$/,
            /\.hbs$/
          ],
          loader: 'url-loader',
          options: {
            limit: 1000,
            publicPath: './',
            // outputPath: commonsChunkPath + '/',
            // name: '[path][name].[hash:8].[ext]'
            name (file) {
              const paths = file.replace(context, '').split('/')
              const res = []
              paths.forEach((path, index) => {
                if (path && index !== paths.length - 1) {
                  res.push(path === 'src' ? 'dist' : path)
                }
              })
              const path = res.join('/')
              return path + '/[name].[hash:8].[ext]'
            }
          }
        }
      ]
    },
    plugins: [
      // new HappyPack({
      //     //用id来标识 happypack处理那里类文件
      //   id: 'happyBabel',
      //   //如何处理  用法和loader 的配置一样
      //   loaders: [{
      //     loader: 'babel-loader',
      //   }],
      //   //共享进程池
      //   threadPool: happyThreadPool,
      //   //允许 HappyPack 输出日志
      //   verbose: true,
      // }),
      // new HappyPack({
      //     //用id来标识 happypack处理那里类文件
      //   id: 'happyEslint',
      //   //如何处理  用法和loader 的配置一样
      //   loaders: [{
      //     loader: 'eslint-loader',
      //   }],
      //   //共享进程池
      //   threadPool: happyThreadPool,
      //   //允许 HappyPack 输出日志
      //   verbose: true
      // })
    ]
  }
  return {
    webpackConfig,
    templates
  }
}

// 处理文件入口路径问题, 处理不是很严谨
function solveEntry (entry, templates, filePath, templatePath) {
  let entryPath = filePath
  if (_.includes(filePath, '.')) {
    entryPath = entryPath.substring(0, entryPath.lastIndexOf('.'))
  }

  // const index = entryPath.indexOf('src')
  entryPath = entryPath.replace('src', 'dist')
  // const filename = index > 0 ? entryPath.substring(0, index - 1) : 'index'

  entry[entryPath] = './' + filePath
  templates.push({
    filePath,
    filename: entryPath + '.html',
    template: templatePath,
    chunk: entryPath,
    basePath: entryPath.substring(0, entryPath.indexOf('dist') + 4)
  })
}

// 将文件处理成统一格式
function handleFiles (files, index) {
  const res = {}
  _.each(files, (item, key) => {
    // 对象形式
    if (_.isString(key)) {
      if (item === 1) {
        res[key] = index
      } else if (_.isString(item)) {
        res[key] = item
      }
    } else {
      if (_.isString(item)) {
        res[item] = index
      } else if (_.isArray(item)) {
        res[item[0]] = item[1]
      }
    }
  })

  return res
}

module.exports = {
  userConfig,
  webpackConfig,
  templates
}
